@@ -8,6 +8,12 @@ import py_eureka_client.eureka_client as eureka_client
 async def post(path, data=None,
                base_url=tornado.options.options.data_server,
                result_type="json", pack=False, **kwargs):
+    flag = kwargs.pop("flag", True)
+    if flag:
+        if not kwargs.get("headers"):
+            kwargs.update({"headers": {
+                "Content-Type": "application/json"
+            }})
     async with aiohttp.ClientSession() as session:
         flag = kwargs.pop("flag", True)
         if flag:
@@ -65,8 +71,15 @@ def sync_get(path, params=None, base_url=tornado.options.options.data_server, re
 def sync_post(path, data=None,
               base_url=tornado.options.options.data_server,
               result_type="json", pack=False, **kwargs):
-    kwargs.pop("flag", True)
-    res = requests.post(base_url + path, data=data, **kwargs)
+    flag = kwargs.pop("flag", True)
+    if flag:
+        if not kwargs.get("headers"):
+            kwargs.update({"headers": {
+                "Content-Type": "application/json"
+            }})
+        res = requests.post(base_url + path, json=data, **kwargs)
+    else:
+        res = requests.post(base_url + path, data=data, **kwargs)
     if result_type == "json":
         res = res.json()
         if not pack:
@@ -79,11 +92,12 @@ def sync_post(path, data=None,
 
 
 def eureka_request(path="", return_type="json", method="GET", data=None, app_name="DATA_SERVICE", pack=False, **kwargs):
-    if not kwargs.get("headers"):
-        kwargs.update({"headers": {
-            "Content-Type": "application/json"
-        }})
-    kwargs.pop("flag", True)
+    flag = kwargs.pop("flag", True)
+    if flag:
+        if not kwargs.get("headers"):
+            kwargs.update({"headers": {
+                "Content-Type": "application/json"
+            }})
     res = eureka_client.do_service(app_name=app_name, service=path, return_type=return_type, method=method, data=data,
                                    **kwargs)
     if return_type == "json" and not pack:
